@@ -1,4 +1,8 @@
-from pywttr_models import (
+"""Pydantic models for pywttr and aiopywttr."""
+from __future__ import annotations
+
+# pylint: disable-next=redefined-builtin
+from . import (
     af,
     am,
     ar,
