@@ -1,8 +1,10 @@
+from __future__ import annotations
+
 from typing import List
 
 from pydantic import Field
 
-from pywttr_models import base
+from . import base
 
 
 class CurrentConditionItem(base.CurrentConditionItem):
